@@ -3,8 +3,11 @@ from __future__ import (absolute_import, division, print_function,
 
 import sys
 
+sys.path.append("../../")
+
+from nginqcomm.common import enums
+
 sys.path.append("../")
-from common import enums
 from utils import maths
 
 # @brief 报价币的数量转换为张数（size）
